/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.debug;

import java.util.Enumeration;
import java.util.Stack;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.MultiStatus;
import org.eclipse.core.runtime.Status;

import be.ac.vub.cocompose.debug.Debug;
import be.ac.vub.cocompose.eclipse.CoComposePlugin;

/**
 * Core Eclipse debugging functionality.
 * @author Dennis Wagelaar
 * @version 0.2.7, 16/03/2004
 * @since 0.2.7
 */
public class EclipseDebug implements Debug
{
  private Stack lastLogs = new Stack();
  
  /**
   * Returns true when in debugging mode.
   * @return true when in debugging mode.
   */
  public boolean debug()
  {
    return CoComposePlugin.getDefault().isDebugging();
  }
  
  /**
   * Logs a message.
   * @param message the log message.
   * @param exception the related exception, if any.
   * @see org.eclipse.core.runtime.IStatus
   */
  public void log(String message, Throwable exception)
  {
  	Enumeration levels = lastLogs.elements();
  	while (levels.hasMoreElements())
  	{
      levels.nextElement();
      message = "    " + message;
  	}
    IStatus st = new Status(
      IStatus.INFO,
      CoComposePlugin.getDefault().getDescriptor().getUniqueIdentifier(),
      IStatus.OK, message, exception);
    if (lastLogs.size() == 1)
    {
      IStatus root = (IStatus) lastLogs.pop();
      if (!(root instanceof MultiStatus))
      {
        root = new MultiStatus(
          root.getPlugin(), root.getCode(), root.getMessage(), root.getException());
      }
      lastLogs.push(root);
    }
    if (!lastLogs.isEmpty())
      ((MultiStatus) lastLogs.get(0)).add(st);
    lastLogs.push(st);
  }
  
  /**
   * End marker for the last log message. Following log messages
   * will be logged independantly.
   */
  public void endLog()
  {
    if (!lastLogs.isEmpty())
    {
      IStatus st = (IStatus) lastLogs.pop();
      if (lastLogs.isEmpty())
      {
        CoComposePlugin.getDefault().getLog().log(st);
      }
    }
  }
}
