/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.debug;

import java.io.InputStream;

import be.ac.vub.cocompose.debug.Debug;
import be.ac.vub.cocompose.eclipse.CoComposePlugin;
import be.ac.vub.cocompose.lang.ModelFactory;

/**
 * CoCompose2 I/O debugging code.
 * @author Dennis Wagelaar
 * @version 0.2.7, 16-apr-2004
 * @since 0.2.7
 */
public aspect IODebug
{
  private static Debug debug = CoComposePlugin.getDefault().getDebug();

  before(String uri, ModelFactory factory):
    args(uri, factory) &&
    execution(* read(String, ModelFactory))
  {
    beforeRead(uri);
  }

  before(InputStream input, ModelFactory factory):
    args(input, factory) &&
    execution(* read(InputStream, ModelFactory))
  {
    beforeRead(input.toString());
  }
  
  after():
    execution(* read(String, ModelFactory)) ||
    execution(* read(InputStream, ModelFactory))
  {
  	endLogging();
  }

  /**
   * Logs a message before a read().
   * @param msg The message to log.
   */
  public static void beforeRead(String msg)
  {
    if (debug != null)
    {
      debug.log("reading model from " + msg, null);
    }
  }

  /**
   * Ends logging.
   */
  public static void endLogging()
  {
    if (debug != null)
    {
      debug.endLog();
    }
  }
}
