/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.debug;

import org.xml.sax.Attributes;

import be.ac.vub.cocompose.debug.Debug;
import be.ac.vub.cocompose.eclipse.CoComposePlugin;

/**
 * XMI parsing and writing debugging code.
 * @author Dennis Wagelaar
 * @version 0.2.7, 16/04/2004
 * @since 0.2.7
 */
public aspect XMIDebug
{
  private static Debug debug = CoComposePlugin.getDefault().getDebug();
  
  before(String uri, String local, String raw, Attributes attrs):
	args(uri, local, raw, attrs) &&
    execution(* startElement(String, String, String, Attributes))
  {
    beforeStartElement(uri + local + raw);
  }
  
  before(String uri, String local, String raw):
    args(uri, local, raw) &&
    execution(* endElement(String, String, String))
  {
    beforeEndElement(uri + local + raw);
  }
  
  /**
   * Logs a message before a startElement().
   * @param msg The message to log.
   */
  public static void beforeStartElement(String msg)
  {
    if (debug != null)
    {
      debug.log("start " + msg, null);
    }
  }

  /**
   * Logs a message before an endElement().
   * @param msg The message to log.
   */
  public static void beforeEndElement(String msg)
  {
    if (debug != null)
    {
      debug.endLog();
      debug.log("end " + msg, null);
      debug.endLog();
    }
  }
}
