/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.editparts;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.Collections;
import java.util.List;

import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.editparts.AbstractTreeEditPart;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;

import be.ac.vub.cocompose.eclipse.CoComposeImages;
import be.ac.vub.cocompose.eclipse.editpolicies.CoComposeElementEditPolicy;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.ModelElement;

/**
 * Eclipse tree editpart for CoCompose elements.
 * @author Dennis Wagelaar
 * @version 0.2.0, 08/01/2004
 * @since 0.2.0
 */
public class CoComposeTreeEditPart
  extends AbstractTreeEditPart
  implements PropertyChangeListener
{
  /**
   * Creates a CoComposeTreeEditPart.
   * @param model the model to edit.
   */
  public CoComposeTreeEditPart(Object model)
  {
    super(model);
  }
  
  /**
   * @see java.beans.PropertyChangeListener#propertyChange(java.beans.PropertyChangeEvent)
   */
  public void propertyChange(PropertyChangeEvent evt)
  {
    if (evt.getPropertyName().equals(Properties.ID_OWNED_ELEMENTS))
      refreshChildren();
    else
      refreshVisuals();
  }

  /**
   * @see org.eclipse.gef.EditPart#activate()
   */
  public void activate()
  {
    super.activate();
    getModelElement().addPropertyChangeListener(this);
  }

  /**
   * @see org.eclipse.gef.EditPart#deactivate()
   */
  public void deactivate()
  {
    getModelElement().removePropertyChangeListener(this);
    super.deactivate();
  }

  /**
   * @see org.eclipse.gef.editparts.AbstractEditPart#createEditPolicies()
   */
  protected void createEditPolicies() 
  {
    EditPolicy component;
    component = new CoComposeElementEditPolicy();
    installEditPolicy(EditPolicy.COMPONENT_ROLE, component);
    // TODO dnd
//    installEditPolicy(EditPolicy.PRIMARY_DRAG_ROLE, new LogicTreeEditPolicy());
  }

  /**
   * Gets the model of this as a ModelElement.
   * @return Model of this.
   */
  protected ModelElement getModelElement() 
  {
    return (ModelElement) getModel();
  }

  /**
   * Returns <code>null</code> as a Tree EditPart holds
   * no children under it.
   * @return <code>null</code>
   */
  protected List getModelChildren() 
  {
    return Collections.EMPTY_LIST;
  }

  /**
   * Refreshes the visual representation.
   */
  protected void refreshVisuals()
  {
    if (getWidget() instanceof Tree)
      return;
    TreeItem item = (TreeItem) getWidget();
    Image image = CoComposeImages.getInstance().getElementIcon(getModelElement());
    if (image != null)
      image.setBackground(item.getParent().getBackground());
    setWidgetImage(image);
    setWidgetText(getModelElement().getName());
  }
}
