/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.editparts;

import java.beans.PropertyChangeEvent;
import java.util.List;

import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.Namespace;
import be.ac.vub.cocompose.lang.core.RelationElement;

/**
 * Eclipse editpart controller for EclipseNamespace objects.
 * @author Dennis Wagelaar
 * @version 0.2.0, 02/12/2003
 * @since 0.2.0
 */
public abstract class NamespaceEditPart extends ModelElementEditPart
{
  /**
   * Handles changes in properties of this. It is
   * activated through the PropertyChangeListener.
   * It updates children, source and target connections,
   * and the visuals of this based on the property
   * changed.
   * @param evt  Event which details the property change.
   * @see java.beans.PropertyChangeListener#propertyChange(java.beans.PropertyChangeEvent)
   */
  public void propertyChange(PropertyChangeEvent evt)
  {
    if (Properties.ID_OWNED_ELEMENTS.equals(evt.getPropertyName())) 
      refreshChildren();
    else
      super.propertyChange(evt);
  }

  /**
   * @see org.eclipse.gef.editparts.AbstractEditPart#createEditPolicies()
   */
  protected void createEditPolicies()
  {
    super.createEditPolicies();
//    installEditPolicy(EditPolicy.CONTAINER_ROLE, new CoComposeContainerEditPolicy());
  }

  /**
   * Gets the model associated with this.
   * @return the model of this.
   */
  protected Namespace getNamespace()
  {
    return (Namespace) getModel();
  }
  
  /**
   * Gets the elements owned by the model associated with this.
   * @return the elements owned by the model.
   */
  protected List getOwnedElements()
  {
    return getNamespace().getOwnedElements();
  }

  /**
   * Returns the children of this through the model.
   * @return  Children of this as a List.
   * @see org.eclipse.gef.editparts.AbstractEditPart#getModelChildren()
   */
  protected List getModelChildren()
  {
    return getNamespace().getOwnedElements(RelationElement.class);
  }
}
