/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.wizards;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

import org.eclipse.core.resources.IFile;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.dialogs.WizardNewFileCreationPage;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchWindow;

import be.ac.vub.cocompose.io.ModelWriter;
import be.ac.vub.cocompose.lang.ModelFactory;
import be.ac.vub.cocompose.lang.core.Model;
import be.ac.vub.cocompose.eclipse.CoComposeImages;
import be.ac.vub.cocompose.eclipse.CoComposePlugin;

/**
 * Page for the NewModelWizard.
 * @author Dennis Wagelaar
 * @version 0.2.6, 08/03/2004
 * @since 0.2.0
 * @see NewModelWizard
 */

public class ModelWizardPage
	extends WizardNewFileCreationPage
	implements SelectionListener
{
  private static int ModelCount = 1;

  private IWorkbench workbench;

  /**
   * Creates a ModelWizardPage.
   * @param workbench - The Eclipse workbench.
   * @param selection - The selection to listen for.
   */
  public ModelWizardPage(IWorkbench workbench, IStructuredSelection selection)
  {
    super("newModelPage1", selection);
    this.workbench = workbench;
    this.setTitle("New CoCompose Model");
    this.setDescription("Create new CoCompose design language model");
    this.setImageDescriptor(CoComposeImages.NEWMODEL_WIZBAN);
  }

  /**
   * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
   */
  public void createControl(Composite parent) 
  {
    super.createControl(parent);
    this.setFileName("newModel" + ModelCount+ ".cocompose");
  }

  /**
   * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
   */
  public void widgetSelected(SelectionEvent e)
  {
  }

  /**
   * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
   */
  public void widgetDefaultSelected(SelectionEvent e)
  {
  }

  /**
   * Finishes this wizard page.
   * @return true if and only if this page finished succesfully.
   */
  public boolean finish() 
  {
  	if (!getFileName().endsWith(".cocompose"))
  	{
  	  setFileName(getFileName() + ".cocompose");
  	}
    IFile newFile = createNewFile();
    if (newFile == null) 
      return false;
    try
    {
      ModelFactory factory = CoComposePlugin.getDefault().getFactory();
      Model model = factory.createModel();
      ModelWriter writer = (ModelWriter) Class.forName(
        CoComposePlugin.getDefault().getSetting("model.writer")).newInstance();
      ByteArrayOutputStream output = new ByteArrayOutputStream();
      writer.write(model, output);
      newFile.setContents(new ByteArrayInputStream(output.toByteArray()), 
        true, false, null);
      output.close();
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
    // --- end test model --- 
    if (!openFileEditor(newFile))
      return false;
    ModelCount++;
    return true;
  }
  
  /**
   * Opens a file in its editor.
   * @param file - the file to open.
   * @return true if and only if successful.
   */
  private boolean openFileEditor(IFile file)
  {
    try 
    {
      IWorkbenchWindow dwindow = workbench.getActiveWorkbenchWindow();
      IWorkbenchPage page = dwindow.getActivePage();
      if (page != null) 
        page.openEditor(file);
    } 
    catch (org.eclipse.ui.PartInitException e) 
    {
      e.printStackTrace();
      return false;
    }
  	return true;
  }
}
