/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.io;

import java.io.IOException;
import java.io.OutputStream;

import be.ac.vub.cocompose.lang.core.Model;
import be.ac.vub.cocompose.lang.ModelElementException;

/**
 * Generic model writing interface for writing a model to its URI.
 * @author Dennis Wagelaar 
 * @version 0.2.6, 08/03/2004
 * @since 0.2.0
 */
public interface ModelWriter
{
  /**
   * Writes the model to its URI.
   * @param model - the model to write.
   * @exception IOException - if the model could not be written.
   * @exception ModelElementException - if a model element could not be written.
   */
  public void write(Model model) throws IOException, ModelElementException;

  /**
   * Writes the model to an OutputStream.
   * @param model - the model to write.
   * @param output - the stream to write to.
   * @exception IOException - if the model could not be written.
   * @exception ModelElementException - if a model element could not be written.
   */
  public void write(Model model, OutputStream output) throws IOException, ModelElementException;
}
