/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.io.xmi;

/**
 * Contains the constants needed for XMI reading and writing.
 * @author Dennis Wagelaar
 * @version 0.2.0, 08/12/2003
 * @since 0.2.0
 */
public abstract class XMI
{
  public static final String NS     = "xmi";
  public static final String NS_URI = "http://www.omg.org/XMI";
  
  /**
   * Returns the qualified name for the given local name
   * @param lname the local element name, e.g. "type"
   * @return the qualified name, e.g. "xmi:type"
   */
  public static String qName(String lname)
  {
    if (lname.equals("href")) return lname;
    return NS + ':' + lname;
  }
  
  /**
   * CoCompose part of the XMI constants
   */
  public static class CoCompose
  {
    public static final String NS     = "CoCompose";
    public static final String NS_URI = "http://ssel.vub.ac.be/cocompose";

    /**
     * Returns the qualified name for the given local name
     * @param lname the local element name, e.g. "type"
     * @return the qualified name, e.g. "xmi:type"
     */
    public static String qName(String lname)
    {
      if (lname.toUpperCase().charAt(0) == lname.charAt(0))
        return NS + ':' + lname;
      else
        return lname;
    }
  }
  
  /**
   * CoCompose Diagram part of the XMI constants
   */
  public static class Diagram
  {
    public static final String NS     = "Diagram";
    public static final String NS_URI = "http://ssel.vub.ac.be/cocompose/diagram";

    /**
     * Returns the qualified name for the given local name
     * @param lname the local element name, e.g. "type"
     * @return the qualified name, e.g. "xmi:type"
     */
    public static String qName(String lname)
    {
      if (lname.toUpperCase().charAt(0) == lname.charAt(0))
        return NS + ':' + lname;
      else
        return lname;
    }
  }
}
