/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.io.xmi;

import be.ac.vub.cocompose.lang.DefaultModelVisitor;
import be.ac.vub.cocompose.lang.VisitedElement;
import be.ac.vub.cocompose.lang.core.ModelElement;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.core.Namespace;
import be.ac.vub.cocompose.lang.core.Model;
import be.ac.vub.cocompose.lang.core.Relationship;
import be.ac.vub.cocompose.lang.core.RelationElement;
import be.ac.vub.cocompose.lang.core.Refinement;
import be.ac.vub.cocompose.lang.core.SolutionPattern;
import be.ac.vub.cocompose.lang.core.ImplementationGenerator;
import be.ac.vub.cocompose.lang.core.ImplementationRolePart;
import be.ac.vub.cocompose.lang.core.ImplementationPattern;
import be.ac.vub.cocompose.lang.core.RefinedElement;
import be.ac.vub.cocompose.lang.core.Concept;
import be.ac.vub.cocompose.lang.core.Role;
import be.ac.vub.cocompose.lang.constraints.Constraint;
import be.ac.vub.cocompose.lang.constraints.ElementConstraint;
import be.ac.vub.cocompose.lang.constraints.CompositeConstraint;
import be.ac.vub.cocompose.lang.constraints.AndConstraint;
import be.ac.vub.cocompose.lang.constraints.OrConstraint;
import be.ac.vub.cocompose.lang.properties.Property;
import be.ac.vub.cocompose.lang.properties.SimpleProperty;
import be.ac.vub.cocompose.lang.properties.ModelProperty;
import be.ac.vub.cocompose.lang.datatypes.Multiplicity;

/**
 * Retrieves the xmi:type for each model element.
 * @author Dennis Wagelaar
 * @version 0.2.0, 09/01/2004
 * @since 0.2.0
 */
public class XMIElementType extends DefaultModelVisitor 
{
  private String type = null;

  /**
   * Gets the element xmi:type.
   * @return the element type.
   */
  public String getType()
  {
    return type;
  }

  /**
   * Visits a ModelElement.
   * @param modelElement - the element to visit.
   * @exception ModelElementException
   */
  public void visitModelElement(ModelElement modelElement) throws ModelElementException
  {
    type = XMI.CoCompose.qName("ModelElement");
  }

  /**
   * Visits a Namespace.
   * @param namespace - the element to visit.
   * @exception ModelElementException
   */
  public void visitNamespace(Namespace namespace) throws ModelElementException
  {
    type = XMI.CoCompose.qName("Namespace");
  }

  /**
   * Visits a Model.
   * @param model - the element to visit.
   * @exception ModelElementException
   */
  public void visitModel(Model model) throws ModelElementException
  {
    type = XMI.CoCompose.qName("Model");
  }

  /**
   * Visits a Relationship.
   * @param relationship - the element to visit.
   * @exception ModelElementException
   */
  public void visitRelationship(Relationship relationship) throws ModelElementException
  {
    type = XMI.CoCompose.qName("Relationship");
  }

  /**
   * Visits a RelationElement.
   * @param relationElement - the element to visit.
   * @exception ModelElementException
   */
  public void visitRelationElement(RelationElement relationElement) throws ModelElementException
  {
    type = XMI.CoCompose.qName("RelationElement");
  }

  /**
   * Visits a Refinement.
   * @param refinement - the element to visit.
   * @exception ModelElementException
   */
  public void visitRefinement(Refinement refinement) throws ModelElementException
  {
    type = XMI.CoCompose.qName("Refinement");
  }

  /**
   * Visits a SolutionPattern.
   * @param solutionPattern - the element to visit.
   * @exception ModelElementException
   */
  public void visitSolutionPattern(SolutionPattern solutionPattern) throws ModelElementException
  {
    type = XMI.CoCompose.qName("SolutionPattern");
  }

  /**
   * Visits an ImplementationGenerator.
   * @param implementationGenerator - the element to visit.
   * @exception ModelElementException
   */
  public void visitImplementationGenerator(ImplementationGenerator implementationGenerator) throws ModelElementException
  {
    type = XMI.CoCompose.qName("ImplementationGenerator");
  }

  /**
   * Visits an ImplementationRolePart.
   * @param rolePart - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitImplementationRolePart(ImplementationRolePart rolePart) throws ModelElementException
  {
    type = XMI.CoCompose.qName("ImplementationRolePart");
  }

  /**
   * Visits an ImplementationPattern.
   * @param implementationPattern - the element to visit.
   * @exception ModelElementException
   */
  public void visitImplementationPattern(ImplementationPattern implementationPattern) throws ModelElementException
  {
    type = XMI.CoCompose.qName("ImplementationPattern");
  }

  /**
   * Visits a RefinedElement.
   * @param refinedElement - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitRefinedElement(RefinedElement refinedElement) throws ModelElementException
  {
    type = XMI.CoCompose.qName("RefinedElement");
  }

  /**
   * Visits a concept.
   * @param concept - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitConcept(Concept concept) throws ModelElementException
  {
    type = XMI.CoCompose.qName("Concept");
  }

  /**
   * Visits a Role.
   * @param role - the element to visit.
   * @exception ModelElementException
   */
  public void visitRole(Role role) throws ModelElementException
  {
    type = XMI.CoCompose.qName("Role");
  }

  /**
   * Visits a Constraint.
   * @param constraint - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitConstraint(Constraint constraint) throws ModelElementException
  {
    type = XMI.CoCompose.qName("Constraint");
  }

  /**
   * Visits an ElementConstraint.
   * @param elementConstraint - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitElementConstraint(ElementConstraint elementConstraint) throws ModelElementException
  {
    type = XMI.CoCompose.qName("ElementConstraint");
  }

  /**
   * Visits a CompositeConstraint.
   * @param compositeConstraint - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitCompositeConstraint(CompositeConstraint compositeConstraint) throws ModelElementException
  {
    type = XMI.CoCompose.qName("CompositeConstraint");
  }

  /**
   * Visits an AndConstraint.
   * @param andConstraint - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitAndConstraint(AndConstraint andConstraint) throws ModelElementException
  {
    type = XMI.CoCompose.qName("AndConstraint");
  }

  /**
   * Visits an OrConstraint.
   * @param orConstraint - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitOrConstraint(OrConstraint orConstraint) throws ModelElementException
  {
    type = XMI.CoCompose.qName("OrConstraint");
  }

  /**
   * Visits a Property.
   * @param property - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitProperty(Property property) throws ModelElementException
  {
    type = XMI.CoCompose.qName("Property");
  }

  /**
   * Visits a SimpleProperty.
   * @param simpleProperty - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitSimpleProperty(SimpleProperty simpleProperty) throws ModelElementException
  {
    type = XMI.CoCompose.qName("SimpleProperty");
  }

  /**
   * Visits a ModelProperty.
   * @param modelProperty - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitModelProperty(ModelProperty modelProperty) throws ModelElementException
  {
    type = XMI.CoCompose.qName("ModelProperty");
  }

  /**
   * Visits a Multiplicity.
   * @param multiplicity - the element to visit.
   * @exception <{ModelElementException}>*/
  public void visitMultiplicity(Multiplicity multiplicity) throws ModelElementException
  {
    type = XMI.CoCompose.qName("Multiplicity");
  }

  /**
   * Starts the visitor.
   * @param visitedElement - the element to start visiting at.
   * @exception ModelElementException
   */
  public void visit(VisitedElement visitedElement) throws ModelElementException
  {
    type = null;
    visitedElement.accept(current);
  }
}
