/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang;

import be.ac.vub.cocompose.lang.core.ModelElement;

/**
 * Exceptions that have a CoCompose language element as their subject.
 * @author Dennis Wagelaar 
 * @version 0.2.0, 09/01/2003
 * @since 0.2.0
 */
public class ModelElementException extends Exception 
{
  public final static int ERROR = 0;
  public final static int WARNING = 1;
  public final static int INFO = 2;

  private ModelElement subject;
  private int type;

  /**
   * Creates a ModelElementException.
   * @param message the exception message
   * @param subject the subject of the exception
   * @param type the exception type (error, warning, info)
   */
  public ModelElementException(String message, ModelElement subject, int type)
  {
    super(message);
    setSubject(subject);
		setType(type);
  }

  /**
   * Creates a ModelElementException.
   * @param message the exception message
   * @param subject the subject of the exception
   */
  public ModelElementException(String message, ModelElement subject)
  {
    this(message, subject, ERROR);
  }

  /**
   * Creates a ModelElementException.
   * @param message the exception message
   */
  public ModelElementException(String message)
  {
    this(message, null, ERROR);
  }

  /**
   * Creates a ModelElementException.
   * @param exception embedded exception to pass on
   */
  public ModelElementException(Exception exception)
  {
    this(exception.getMessage());
    setStackTrace(exception.getStackTrace());
  }

  /**
   * Creates a ModelElementException.
   * @param exception embedded exception to pass on
   * @param subject the subject of the exception
   */
  public ModelElementException(Exception exception, ModelElement subject)
  {
    this(exception.getMessage(), subject);
    setStackTrace(exception.getStackTrace());
  }

  /**
   * Creates a ModelElementException.
   * @param exception embedded exception to pass on
   * @param subject the subject of the exception
   * @param type the exception type (error, warning, info)
   */
  public ModelElementException(Exception exception, ModelElement subject, int type)
  {
    this(exception.getMessage(), subject, type);
    setStackTrace(exception.getStackTrace());
  }

  /**
   * Creates a ModelElementException.
   * @param exception embedded exception to pass on
   */
  public ModelElementException(ModelElementException exception)
  {
    this(exception.getMessage(), exception.getSubject(), exception.getType());
    setStackTrace(exception.getStackTrace());
  }

  /**
   * Gets the exception subject element.
   * @return the exception subject.
   */
  public ModelElement getSubject()
  {
    return subject;
  }

  /**
   * Sets the exception subject.
   * @param subject the exception subject.
   */
  public void setSubject(ModelElement subject)
  {
    this.subject = subject;
  }

  /**
   * Gets the exception type (error, warning, info)
   * @return the exception type.
   */
  public int getType()
  {
    return type;
  }

  /**
   * Sets the exception type (error, warning, info).
   * @param type the exception type.
   */
  public void setType(int type)
  {
    this.type = type;
  }

}
