/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.core;

import java.awt.Color;
import java.awt.Point;
import java.util.List;

/**
 * Interface for all CoCompose language elements that can participate in a relationship.
 * @author Dennis Wagelaar
 * @version 0.2.0, 02/12/2003
 * @since 0.2.0 
 */
public interface RelationElement extends Namespace
{
  /**
   * Gets the relationships for this element.
   * @return the list of relationships.
   */
  public List getRelationships();

  /**
   * Gets the source relationships for this element.
   * @return the list of source relationships.
   */
  public List getSourceRelationships();

  /**
   * Gets the target relationships for this element.
   * @return the list of target relationships.
   */
  public List getTargetRelationships();

  /**
   * Adds a relationship for this element.
   * @param relationship - the relationship to add.
   */
  public void addRelationship(Relationship relationship);

  /**
   * Adds a relationship for this element at the specified index.
   * @param index - the index at which to add the relationship.
   * @param relationship - the relationship to add.
   */
  public void addRelationship(int index, Relationship relationship);

  /**
   * Removes a relationship from this element.
   * @param relationship - the relationship to remove. 
   */
  public void removeRelationship(Relationship relationship);

  /**
   * Gets the element position.
   * @return the position.
   */
  public Point getPosition();

  /**
   * Sets the element position.
   * @param position - the position.
   */
  public void setPosition(Point position);

  /**
   * Gets the background color.
   * @return the background color.
   */
  public Color getBackgroundColor();

  /**
   * Sets the background color.
   * @param bgcolor - the background color.
   */
  public void setBackgroundColor(Color bgcolor);
}
