package be.ac.vub.cocompose.lang.datatypes;

import be.ac.vub.cocompose.lang.VisitedElement;
import be.ac.vub.cocompose.lang.ModelVisitor;
import be.ac.vub.cocompose.lang.ModelElementException;

/**
 * Multiplicity constraint interface.
 * @author Dennis Wagelaar 
 * @version 0.2.0
 * @since 0.2.0
 */
public class Multiplicity implements VisitedElement
{
  /**
   * Represents many elements. 
   */
  public final static int MANY = -1;

  private int lower = 0;
  private int upper = MANY;

  /**
   * Creates a Multiplicity.
   */
  public Multiplicity()
  {
    super();
  }
  
  /**
   * Creates a Multiplicity from the given source.
   * @param source - the source multiplicity to copy the values from.
   */
  public Multiplicity(Multiplicity source)
  {
    super();
    setLower(source.getLower());
    setUpper(source.getUpper());
  }

  /**
   * Gets the lower bound.
   * @return the lower bound.
   */
  public int getLower()
  {
    return lower;
  }

  /**
   * Sets the lower bound.
   * @param lower - the lower bound.
   */
  public void setLower(int lower)
  {
    this.lower = lower;
  }

  /**
   * Gets the upper bound.
   * @return the upper bound.
   */
  public int getUpper()
  {
    return upper;
  }

  /**
   * Sets the upper bound.
   * @param upper - the upper bound.
   */
  public void setUpper(int upper)
  {
    this.upper = upper;
  }

  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.
   */
  public void accept(ModelVisitor modelVisitor) throws ModelElementException
  {
    modelVisitor.visitMultiplicity(this);
  }

  /**
   * Invokes superclass accept().
   * @param modelVisitor The visitor to accept.
   * @see #accept(ModelVisitor)
   */
  public void acceptSuper(ModelVisitor modelVisitor) throws ModelElementException
  {
  }
  
  /**
   * Returns [lowerbound..upperbound].
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    String lower, upper;
    if (getLower() == MANY)
      lower = "*";
    else
      lower = Integer.toString(getLower());
    if (getUpper() == MANY)
      upper = "*";
    else
      upper = Integer.toString(getUpper());
    return "[" + lower + ".." + upper + "]";
  }
}
